summaryrefslogtreecommitdiffstats
path: root/modules/context/repo.go
diff options
context:
space:
mode:
Diffstat (limited to 'modules/context/repo.go')
-rw-r--r--modules/context/repo.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/modules/context/repo.go b/modules/context/repo.go
index bc58b490eb..af18881486 100644
--- a/modules/context/repo.go
+++ b/modules/context/repo.go
@@ -275,8 +275,8 @@ func RepoAssignment(args ...bool) macaron.Handler {
}
}
- // People who have push access and propose a new pull request.
- if ctx.Repo.IsWriter() {
+ // People who have push access or have fored repository can propose a new pull request.
+ if ctx.Repo.IsWriter() || (ctx.IsSigned && ctx.User.HasForkedRepo(ctx.Repo.Repository.ID)) {
// Pull request is allowed if this is a fork repository
// and base repository accepts pull requests.
if repo.BaseRepo != nil {